const { Property } = require('../entities/config/data-access')

exports.seed = async (knex, Promise) => {
  // Initial table data
  const seeds = [
    {
      name: 'homeNotification',
      description: 'Login page notification settings',
      schema: JSON.stringify({
        $schema: 'https://json-schema.org/draft/2020-12/schema',
        type: 'object',
        properties: {
          display: {
            type: 'boolean',
            description: 'Show notification on login page',
          },
          kind: {
            type: 'string',
            enum: ['warning', 'error', 'info', 'success'],
            description: 'Notification type',
          },
          message: {
            type: 'string',
            format: 'block',
            description: 'Notification message text',
          },
          startDate: {
            type: 'string',
            format: 'date-time',
            description: 'Start date for notification (optional)',
          },
          stopDate: {
            type: 'string',
            format: 'date-time',
            description: 'End date for notification (optional)',
          },
        },
        required: ['display', 'kind', 'message'],
      }),
      value: JSON.stringify({
        display: false,
        kind: 'warning',
        message:
          'We are currently experiencing technical issues affecting the ability to create and review submissions. We are working to resolve these issues, and apologise for any inconvenience.',
      }),
    },
    {
      name: 'holidayNotification',
      description: 'Login page holiday notice settings',
      schema: JSON.stringify({
        $schema: 'https://json-schema.org/draft/2020-12/schema',
        type: 'object',
        properties: {
          display: { type: 'boolean', description: 'Show holiday notice' },
          startDate: {
            type: 'string',
            format: 'date-time',
            description: 'Start date for holiday message',
          },
          stopDate: {
            type: 'string',
            format: 'date-time',
            description: 'End date for holiday message',
          },
        },
        required: ['display', 'startDate', 'stopDate'],
      }),
      value: JSON.stringify({
        display: false,
        startDate: '2020-12-25T00:00:00Z',
        stopDate: '2021-01-03T00:00:00Z',
      }),
    },
    {
      name: 'approvedServers',
      description: 'List of preprint servers to skip submission QA',
      schema: JSON.stringify({
        $schema: 'https://json-schema.org/draft/2020-12/schema',
        type: 'array',
        items: { type: 'string', description: 'Server name' },
      }),
      value: JSON.stringify(['medRxiv', 'bioRxiv', 'Res Sq', 'SSRN', 'ArXiv']),
    },
    {
      name: 'planSFunders',
      description:
        'Plan S/Horizon Europe funder information. Check value only needed if not default date (2021-01-01T00:00:00.000Z) or category (Plan S).',
      schema: JSON.stringify({
        $schema: 'https://json-schema.org/draft/2020-12/schema',
        type: 'array',
        items: {
          type: 'object',
          properties: {
            funderName: { type: 'string', description: 'Funder name' },
            checkStrategy: {
              type: 'string',
              enum: ['grant date', 'submit date', 'category'],
              default: 'grant date',
              description: 'Grant checking strategy',
            },
            checkValue: {
              type: ['string', 'null'],
              description: 'Check value (optional)',
            },
            exceptionEmail: {
              type: 'string',
              format: 'email',
              description: 'Exception query email address',
            },
          },
          required: ['funderName', 'exceptionEmail', 'checkStrategy'],
        },
      }),
      value: JSON.stringify([
        {
          funderName: 'Wellcome Trust',
          checkStrategy: 'submit date',
          exceptionEmail: 'helpdesk@europepmc.org',
        },
      ]),
    },
  ]

  // Inserts seed entries if name not already in database
  const props = await Property.selectAll()

  const newProps = seeds.reduce((arr, s) => {
    if (!props.some(p => p.name === s.name)) arr.push(s)
    return arr
  }, [])

  return knex('config.property').insert(newProps)
}
