const logger = require('@pubsweet/logger')
const Role = require('../entities/role/data-access')
const Organization = require('../entities/organization/data-access')

exports.seed = async (knex, Promise) => {
  // Checking
  const orgs = await Organization.selectAll()
  if (!orgs.find(org => org.name === 'Europe PMC Preprints')) {
    logger.info('Seeding preprint org.')
    await knex('organization').insert([
      {
        name: 'Europe PMC Preprints',
      },
    ])
  }
  const role = await Role.selectByName('admin')
  if (role) {
    logger.info('Good. Already seeded.')
    return
  }

  // Seed main organization
  await knex('organization').del()
  await knex('organization').insert([
    {
      name: 'Europe PMC Plus',
    },
    {
      name: 'Europe PMC Preprints',
    },
  ])

  // Seed roles
  await knex('role').insert([
    { name: 'admin', organization: true },
    { name: 'external-admin', organization: true },
    { name: 'submitter', organization: false },
    { name: 'reviewer', organization: false },
    { name: 'tagger', organization: true },
  ])

  // Seed versions
  await knex('privacy_notice').insert([
    { version: 2, effective_date: new Date('2018-05-24') },
    { version: 3, effective_date: new Date('2018-08-23') },
  ])
}
